@@ -391,8 +391,11 @@ class GitlabClient:
             self.client.projects.get, project_id, statuses_to_retry=GITLAB_STATUSES_TO_RETRY
         )
 
+        # We use pagination here instead of using the iterator kwarg. The generator bypasses our retry_for_status check.
+        # We can get ChunkedEncodingErrors, which is handled by retry_for_status.
         kwargs_dict: dict[str, Any] = {
-            'iterator': True,  # Returns a generator
+            'page': 1,
+            'per_page': 100,
         }
         if branch_name:
             kwargs_dict['ref_name'] = branch_name
@@ -402,8 +405,14 @@ class GitlabClient:
             kwargs_dict['until'] = until
 
         try:
-            for commit in retry_for_status(project.commits.list, statuses_to_retry=GITLAB_STATUSES_TO_RETRY, **kwargs_dict):  # type: ignore
-                yield commit
+            while True:
+                commits = retry_for_status(project.commits.list, statuses_to_retry=GITLAB_STATUSES_TO_RETRY, **kwargs_dict)  # type: ignore
+                if not commits:
+                    break
+                for commit in commits:
+                    yield commit
+                kwargs_dict['page'] += 1
+
         except (requests.exceptions.ConnectionError, GitlabError, RetryLimitExceeded) as e:
             logger.warning(
                 f"Failed to pull commits for repo {jf_repo.name}. Skipping. Exception: {e}"
