@@ -34,6 +34,7 @@ from jf_ingest.jf_jira.downloaders import (
     download_worklogs,
     get_issue_ids_for_rekeys_and_deletes,
     get_jira_search_batch_size,
+    is_jql_enhanced_search_available,
     pull_all_jira_issues_by_date,
     pull_jira_issues_by_jira_ids,
 )
@@ -191,6 +192,7 @@ def pull_issues_wrapper(
     jira_issues_batch_size: int,
     ingest_io_helper: IngestIOHelper,
     ingest_config: IngestionConfig,
+    use_jql_enhanced_search: bool = False,
 ) -> tuple[set[str], set[str], set[UserMetadata]]:
     """Pulls issues using the "new" sync path, based on our ability to pull 10,000 jira issue IDs at one time
         as long as you only ask for `id` and `key` in the returned fields. Because we get no more fields we detect
@@ -202,6 +204,7 @@ def pull_issues_wrapper(
         jira_issues_batch_size: batch size to use for actually downloading issues (much lower than the 10k for IDs)
         ingest_io_helper: IngestIOHelper object for doing file operations
         ingest_config: full jf_ingest config
+        use_jql_enhanced_search: whether to use JQL Enhanced Search API (/search/jql) or legacy API (/search)
 
     Returns:
         tuple[set[str], set[str], set[UserMetadata]]: returns a tuple of three sets:
@@ -232,6 +235,7 @@ def pull_issues_wrapper(
             },
             pull_from=jira_config.pull_from,
             jql_filter=jira_config.issue_jql_filter,
+            use_jql_enhanced_search=use_jql_enhanced_search,
         )
         ids_to_delete = issue_list_diff.ids_to_delete
         ids_to_download = issue_list_diff.ids_to_download
@@ -271,6 +275,7 @@ def pull_issues_wrapper(
             expand_fields=["changelog"],
             include_fields=include_fields,
             exclude_fields=exclude_fields,
+            use_jql_enhanced_search=use_jql_enhanced_search,
         )
         with record_span('pull_jira_issues_by_date'):
             issues_by_updated_date_results = load_issues_in_batches(
@@ -310,6 +315,7 @@ def pull_issues_wrapper(
         expand_fields=["changelog"],
         include_fields=include_fields,
         exclude_fields=exclude_fields,
+        use_jql_enhanced_search=use_jql_enhanced_search,
     )
     with record_span('pull_jira_issues_by_ids'):
         issues_by_ids_results: IssueDownloadingResult = load_issues_in_batches(
@@ -367,6 +373,7 @@ def pull_issues_wrapper(
                 include_fields=include_fields,
                 exclude_fields=exclude_fields,
                 pull_from=jira_config.pull_from,  # NOTE: We never pull any parents that were last updated before our pull from date! Jira Load WILL NOT load these
+                use_jql_enhanced_search=use_jql_enhanced_search,
             )
             with record_span('write_jira_parent_issues_batch_to_local_or_s3'):
                 parents_batch_result: IssueDownloadingResult = load_issues_in_batches(
@@ -480,13 +487,41 @@ def _run_load_and_push_to_s3(ingest_config: IngestionConfig) -> bool:
 
     #######################################################################
     # SET UP JIRA CONNECTIONS (Basic and Potentially Atlassian Connect)
+    # First create test connection with v3 to check JQL Enhanced Search availability
     #######################################################################
+
+    # Calculate API selection decision first
+    should_attempt_enhanced_search = jira_config.feature_flags.get(
+        Constants.JQL_ENHANCED_SEARCH_ENABLED, False
+    ) and not jira_config.feature_flags.get(Constants.FORCE_LEGACY_API, False)
+
+    # Create test connection with v3 if we should attempt enhanced search
+    use_jql_enhanced_search = False
+    if should_attempt_enhanced_search:
+        try:
+            test_connection = get_jira_connection(
+                config=jira_config,
+                auth_method=JiraAuthMethod.BasicAuth,
+                use_jql_enhanced_search=True,
+            )
+            use_jql_enhanced_search = is_jql_enhanced_search_available(test_connection)
+        except Exception as e:
+            logger.warning(f"Failed to create v3 test connection for JQL Enhanced Search: {e}")
+            use_jql_enhanced_search = False
+
+    # Create final connections with appropriate API version
     jira_basic_connection = get_jira_connection(
-        config=jira_config, auth_method=JiraAuthMethod.BasicAuth
+        config=jira_config,
+        auth_method=JiraAuthMethod.BasicAuth,
+        use_jql_enhanced_search=use_jql_enhanced_search,
     )
 
     jira_atlas_connect_connection = (
-        get_jira_connection(config=jira_config, auth_method=JiraAuthMethod.AtlassianConnect)
+        get_jira_connection(
+            config=jira_config,
+            auth_method=JiraAuthMethod.AtlassianConnect,
+            use_jql_enhanced_search=use_jql_enhanced_search,
+        )
         if JiraAuthMethod.AtlassianConnect in jira_config.available_auth_methods
         else None
     )
@@ -734,11 +769,15 @@ def _run_load_and_push_to_s3(ingest_config: IngestionConfig) -> bool:
         )
 
     if not jira_config.skip_issues:
+        api_type = "JQL Enhanced Search" if use_jql_enhanced_search else "Legacy"
+        logger.info(f"Using {api_type} API for Jira operations")
+
         # For Jira Issue operations we need to determine the batch size that
         # the JIRA provider will limit us to
         jira_issues_batch_size = get_jira_search_batch_size(
             jira_connection=jira_connect_or_fallback_connection,
             optimistic_batch_size=jira_config.issue_batch_size,
+            use_jql_enhanced_search=use_jql_enhanced_search,
         )
 
         all_downloaded_issue_ids, all_deleted_issue_ids, users_found_across_all_issues = (
@@ -751,6 +790,7 @@ def _run_load_and_push_to_s3(ingest_config: IngestionConfig) -> bool:
                 jira_issues_batch_size=jira_issues_batch_size,
                 ingest_io_helper=ingest_io_helper,
                 ingest_config=ingest_config,
+                use_jql_enhanced_search=use_jql_enhanced_search,
             )
         )
 
