@@ -1025,7 +1025,7 @@ def test_get_issue_count_with_jql_enhanced_search_approximate_success():
         _register_jira_uri(
             mocker,
             endpoint="search/approximate-count",
-            return_value='{"approximateCount": 1247}',
+            return_value='{"count": 1247}',
             HTTP_ACTION='POST',
             status_code=200,
         )
@@ -1305,7 +1305,7 @@ def test_get_issue_count_for_jql_with_jql_enhanced_search():
         mocker.register_uri(
             'POST',
             'https://test-co.atlassian.net/rest/api/2/search/approximate-count',
-            json={'approximateCount': PROJECT_ISSUE_COUNT}
+            json={'count': PROJECT_ISSUE_COUNT}
         )
         
         count_for_jql = _get_issue_count_for_jql(
